@@ -1,11 +1,11 @@
 #define NAME          "IPhreeqc"
 #define VER_MAJOR      3
 #define VER_MINOR      8
-#define VER_PATCH      6
-#define VER_REVISION   17100
-#define GIT_COMMIT     47ce8e0adbad8f9dc67a9d977c339a611ba753eb
+#define VER_PATCH      7
+#define VER_REVISION   17149
+#define GIT_COMMIT     75780866714a0cd0f0fa3a3a98426a72b5e4c02f
 
-#define RELEASE_DATE           "January  7, 2025"
+#define RELEASE_DATE           "February 25, 2025"
 
 #define APR_STRINGIFY(n) APR_STRINGIFY_HELPER(n)
 #define APR_STRINGIFY_HELPER(n) #n
