@@ -109,7 +109,7 @@
 #define TRANSPORT		 8
 #define PHAST		     9
 
-/* constaints in mass balance */
+/* constraints in mass balance */
 #define EITHER 0
 #define DISSOLVE 1
 #define PRECIPITATE -1
@@ -210,6 +210,20 @@ struct Change_Surf
 /*----------------------------------------------------------------------
  *   CReaction
  *---------------------------------------------------------------------- */
+class rxn_token
+{
+public:
+	~rxn_token() {};
+	rxn_token()
+	{
+		s = NULL;
+		coef = 0.0;
+		name = NULL;
+	}
+	class species* s;
+	LDBLE coef;
+	const char* name;
+};
 class CReaction
 {
 public:
@@ -229,20 +243,6 @@ public:
 	double dz[3];
 	std::vector<class rxn_token> token;
 };
-class rxn_token
-{
-public:
-	~rxn_token() {};
-	rxn_token()
-	{
-		s = NULL;
-		coef = 0.0;
-		name = NULL;
-	}
-	class species* s;
-	LDBLE coef;
-	const char* name;
-};
 class save
 {
 public:
@@ -322,6 +322,86 @@ public:
 /*----------------------------------------------------------------------
  *   Inverse
  *---------------------------------------------------------------------- */
+class inv_elts
+{
+public:
+	~inv_elts() {};
+	inv_elts()
+	{
+		name = NULL;
+		master = NULL;
+		row = 0;
+		//uncertainties.clear();
+	}
+	const char* name;
+	class master* master;
+	size_t row;
+	std::vector<double> uncertainties;
+};
+class isotope
+{
+public:
+	~isotope() {};
+	isotope()
+	{
+		isotope_number = 0;
+		elt_name = NULL;
+		isotope_name = NULL;
+		total = 0;
+		ratio = 0;
+		ratio_uncertainty = 0;
+		x_ratio_uncertainty = 0;
+		master = NULL;
+		primary = NULL;
+		coef = 0;					/* coefficient of element in phase */
+	}
+	LDBLE isotope_number;
+	const char* elt_name;
+	const char* isotope_name;
+	LDBLE total;
+	LDBLE ratio;
+	LDBLE ratio_uncertainty;
+	LDBLE x_ratio_uncertainty;
+	class master* master;
+	class master* primary;
+	LDBLE coef;
+};
+class inv_isotope
+{
+public:
+	~inv_isotope() {};
+	inv_isotope()
+	{
+		isotope_name = NULL;
+		isotope_number = 0;
+		elt_name = NULL;
+		//uncertainties.clear();
+	}
+	const char* isotope_name;
+	LDBLE isotope_number;
+	const char* elt_name;
+	std::vector<double> uncertainties;
+};
+class inv_phases
+{
+public:
+	~inv_phases() {};
+	inv_phases()
+	{
+		name = NULL;
+		phase = NULL;
+		column = 0;
+		constraint = EITHER;
+		force = FALSE;
+		//isotopes.clear();
+	}
+	const char* name;
+	class phase* phase;
+	int column;
+	int constraint;
+	int force;
+	std::vector<class isotope> isotopes;
+};
 class inverse
 {
 public:
@@ -386,58 +466,6 @@ public:
 	const char* netpath;
 	const char* pat;
 };
-class inv_elts
-{
-public:
-	~inv_elts() {};
-	inv_elts()
-	{
-		name = NULL;
-		master = NULL;
-		row = 0;
-		//uncertainties.clear();
-	}
-	const char* name;
-	class master* master;
-	size_t row;
-	std::vector<double> uncertainties;
-};
-class inv_isotope
-{
-public:
-	~inv_isotope() {};
-	inv_isotope()
-	{
-		isotope_name = NULL;
-		isotope_number = 0;
-		elt_name = NULL;
-		//uncertainties.clear();
-	}
-	const char* isotope_name;
-	LDBLE isotope_number;
-	const char* elt_name;
-	std::vector<double> uncertainties;
-};
-class inv_phases
-{
-public:
-	~inv_phases() {};
-	inv_phases()
-	{
-		name = NULL;
-		phase = NULL;
-		column = 0;
-		constraint = EITHER;
-		force = FALSE;
-		//isotopes.clear();
-	}
-	const char* name;
-	class phase* phase;
-	int column;
-	int constraint;
-	int force;
-	std::vector<class isotope> isotopes;
-};
 /*----------------------------------------------------------------------
  *   Jacobian and Mass balance lists
  *---------------------------------------------------------------------- */
@@ -538,34 +566,6 @@ public:
 	LDBLE* target;
 	LDBLE coef;
 };
-class isotope
-{
-public:
-	~isotope() {};
-	isotope()
-	{
-		isotope_number = 0;
-		elt_name = NULL;
-		isotope_name = NULL;
-		total = 0;
-		ratio = 0;
-		ratio_uncertainty = 0;
-		x_ratio_uncertainty = 0;
-		master = NULL;
-		primary = NULL;
-		coef = 0;					/* coefficient of element in phase */
-	}
-	LDBLE isotope_number;
-	const char* elt_name;
-	const char* isotope_name;
-	LDBLE total;
-	LDBLE ratio;
-	LDBLE ratio_uncertainty;
-	LDBLE x_ratio_uncertainty;
-	class master* master;
-	class master* primary;
-	LDBLE coef;
-};
 class iso
 {
 public:
@@ -981,7 +981,7 @@ public:
 		alk = 0;
 		// default gfw for species
 		gfw = 1;
-		// formula from which to calcuate gfw
+		// formula from which to calculate gfw
 		gfw_formula = NULL;
 		// pointer to unknown structure
 		unknown = NULL;
@@ -1107,20 +1107,6 @@ public:
 /*----------------------------------------------------------------------
  *   Reaction work space
  *---------------------------------------------------------------------- */
-class reaction_temp
-{
-public:
-	~reaction_temp() {};
-	reaction_temp()
-	{
-		for (size_t i = 0; i < MAX_LOG_K_INDICES; i++) logk[i] = 0;
-		for (size_t i = 0; i < 3; i++) dz[i] = 0;
-		//token.clear();
-	}
-	LDBLE logk[MAX_LOG_K_INDICES];
-	LDBLE dz[3];
-	std::vector<class rxn_token_temp> token;
-};
 class rxn_token_temp
 {
 public:
@@ -1139,6 +1125,20 @@ public:
 	class unknown* unknown;
 	LDBLE coef;
 };
+class reaction_temp
+{
+public:
+	~reaction_temp() {};
+	reaction_temp()
+	{
+		for (size_t i = 0; i < MAX_LOG_K_INDICES; i++) logk[i] = 0;
+		for (size_t i = 0; i < 3; i++) dz[i] = 0;
+		//token.clear();
+	}
+	LDBLE logk[MAX_LOG_K_INDICES];
+	LDBLE dz[3];
+	std::vector<class rxn_token_temp> token;
+};
 class unknown_list
 {
 public:
@@ -1486,7 +1486,9 @@ public:
 		c = 0;
 		// charge number
 		z = 0;
-		// temperature corrected free water diffusion coefficient, m2/s
+		// free water diffusion coefficient, m2/s
+		Dw = 0;
+		// temperature and viscosity corrected free water diffusion coefficient, m2/s
 		Dwt = 0;
 		// temperature factor for Dw
 		dw_t = 0;
@@ -1503,6 +1505,7 @@ public:
 	LDBLE lg;
 	LDBLE c;
 	LDBLE z;
+	LDBLE Dw;
 	LDBLE Dwt;
 	LDBLE dw_t;
 	LDBLE dw_a_v_dif;
@@ -1521,17 +1524,17 @@ public:
 		count_exch_spec = 0;
 		// total moles of X-, max X- in transport step in sol_D[1], tk
 		exch_total = 0, x_max = 0, tk_x = 0;
-		// (tk_x * viscos_0_25) / (298 * viscos_0) 
-		viscos_f0 = 0;
-		// (viscos_0) / (298 * viscos) 
-		viscos_f = 0;
+		// viscos_0 at I = 0
+		viscos_0 = 0;
+		// viscosity of solution
+		viscos = 0;
 		spec = NULL;
 		spec_size = 0;
 	}
 	int count_spec;
 	int count_exch_spec;
 	LDBLE exch_total, x_max, tk_x;
-	LDBLE viscos_f0, viscos_f;
+	LDBLE viscos_0, viscos;
 	class spec* spec;
 	int spec_size;
 };
@@ -1581,7 +1584,7 @@ public:
 };
 // Pitzer definitions
 typedef enum
-{ TYPE_B0, TYPE_B1, TYPE_B2, TYPE_C0, TYPE_THETA, TYPE_LAMDA, TYPE_ZETA,
+{ TYPE_B0, TYPE_B1, TYPE_B2, TYPE_C0, TYPE_THETA, TYPE_LAMBDA, TYPE_ZETA,
   TYPE_PSI, TYPE_ETHETA, TYPE_ALPHAS, TYPE_MU, TYPE_ETA, TYPE_Other,
   TYPE_SIT_EPSILON, TYPE_SIT_EPSILON_MU, TYPE_APHI
 } pitz_param_type;
@@ -1613,7 +1616,7 @@ public:
 		LDBLE b2;
 		LDBLE c0;
 		LDBLE theta;
-		LDBLE lamda;
+		LDBLE lambda;
 		LDBLE zeta;
 		LDBLE psi;
 		LDBLE alphas;
